Core API
========

The Core API consists of modules that provide basic functionality such as the cycle based
state machine, control server and client infrastructure and some utilities.

.. toctree::
    :maxdepth: 2

    core/adapters
    core/approaches
    core/control_client
    core/control_server
    core/devices
    core/exceptions
    core/logging
    core/processor
    core/simulation
    core/statemachine
    core/utils
